PsVersionedDescriptorCodec class abstract final

Encodes and decodes 32-bit-versioned Photoshop Action Descriptors.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Uint8List bytes, {int? expectedVersion, PsDescriptorDecodeOptions options = const PsDescriptorDecodeOptions()}) PsVersionedDescriptor
Decodes one complete versioned descriptor.
decodePrefix(Uint8List bytes, {int? expectedVersion, PsDescriptorDecodeOptions options = const PsDescriptorDecodeOptions()}) → ({int bytesRead, PsVersionedDescriptor value})
Decodes one versioned descriptor from the start of bytes.
encode(PsVersionedDescriptor value) Uint8List
Encodes value without an outer length or alignment field.
read(PsBinaryReader reader, {int? expectedVersion, PsDescriptorDecodeOptions options = const PsDescriptorDecodeOptions()}) PsVersionedDescriptor
Reads one versioned descriptor at the current reader position.
write(PsBinaryWriter writer, PsVersionedDescriptor value) → void
Writes value at the current writer position.